@@ -1,3 +1,7 @@
+import cv2
+import numpy as np
+from PIL import ImageDraw, Image
+
 from viso_sdk.visualize.viz_roi import VizPolygonDraw
 from viso_sdk.visualize.viz_object import VizObjectDraw
 from viso_sdk.visualize.palette import get_rgba_color_with_palette_id
@@ -51,16 +55,54 @@ class BaseVisualization:
         )
         return show
 
-    def draw_rois(self, img, rois: list, roi_type: str = 'polygon'):
-        if roi_type == 'polygon':
-            show = self.roi_drawer.draw_polygon_rois(
-                img=img,
-                rois=rois
-            )
-            return show
+    def draw_polygons(self, img, rois):
+        show = self.roi_drawer.draw_polygon_rois(
+            img=img,
+            rois=rois
+        )
+        return show
 
-        elif roi_type == 'line':
-            show = self.roi_drawer.draw_line_rois()
-            return show
-        else:
-            return img
+    def draw_lines(self, img, lines, labels):
+        show = self.roi_drawer.draw_line_rois(
+            img=img,
+            lines=lines,
+            labels=labels)
+        return show
+
+    def put_text(self,
+                 img,
+                 font=None,
+                 text="",
+                 text_color=None,
+                 align="left",
+                 pos=(0, 0),
+                 bbox_color=None,
+                 bbox_thickness=-1,
+                 large_padding=False,
+                 show_shadow=True,
+                 shadow_color=utils.DEFAULT_SHADOW_COLOR):
+        cv_im_rgba = cv2.cvtColor(img.copy(), cv2.COLOR_BGR2RGBA)
+
+        # Pass the image to PIL
+        pil_base_im = Image.fromarray(cv_im_rgba, "RGBA")
+
+        pil_viz_im = Image.new("RGBA", pil_base_im.size, (255, 255, 255, 0))
+        draw = ImageDraw.Draw(pil_viz_im, "RGBA")
+
+        utils.put_text(
+            draw=draw,
+            font=self.default_font if font is None else font,
+            bbox=pos,
+            text=str(text),
+            text_color=utils.DEFAULT_TXT_COLOR if text_color is None else text_color,
+            align=align,
+            large_padding=large_padding,
+            bbox_color=utils.DEFAULT_ROI_COLOR if bbox_color is None else bbox_color,
+            bbox_thickness=bbox_thickness,
+            show_shadow=show_shadow,
+            shadow_color=utils.DEFAULT_SHADOW_COLOR if shadow_color is None else shadow_color
+        )
+
+        pil_out = Image.alpha_composite(pil_base_im, pil_viz_im)
+        cv_im_processed = cv2.cvtColor(np.array(pil_out), cv2.COLOR_RGBA2BGR)
+        return cv_im_processed
