@@ -36,9 +36,9 @@ class VizPolygonDraw:
                 outline_color = utils.DEFAULT_ROI_OUTLINE_COLOR
         self.default_outline_color = get_rgba_color(outline_color)
 
-        # if outline_thickness is None:
-        #     outline_thickness = DEFAULT_ROI_OUTLINE_THICKNESS
-        # self.default_outline_thickness = int(outline_thickness)
+        if outline_thickness is None:
+            outline_thickness = utils.DEFAULT_ROI_OUTLINE_THICKNESS
+        self.default_outline_thickness = int(outline_thickness)
 
         self.label_color = get_rgba_color(label_color)
 
@@ -102,12 +102,11 @@ class VizPolygonDraw:
 
             label = roi.get('roi_name', '')
 
-            self._draw_polygon_(
-                draw=draw,
-                polygon=polygon,
-                fill_color=fill_color,
-                outline_color=outline_color
-            )
+            # if outline_thickness is None:
+            #     outline_thickness = self.default_outline_thickness
+            draw.polygon(xy=polygon,
+                         fill=self.default_roi_color if fill_color is None else fill_color,
+                         outline=self.default_outline_color if outline_color is None else outline_color)
 
             if self.show_label:
                 utils.put_text(
@@ -126,5 +125,56 @@ class VizPolygonDraw:
         cv_im_processed = cv2.cvtColor(np.array(pil_out), cv2.COLOR_RGBA2BGR)
         return cv_im_processed
 
-    def draw_line_rois(self):
-        pass
+    def draw_line_rois(
+            self,
+            img,
+            lines,
+            labels,
+            label_font=None,
+            label_color=None,
+            line_color=None,
+            line_thickness=None
+    ):
+        img_h, img_w, = img.shape[:2]
+
+        cv_im_rgba = cv2.cvtColor(img.copy(), cv2.COLOR_BGR2RGBA)
+
+        # Pass the image to PIL
+        pil_base_im = Image.fromarray(cv_im_rgba, "RGBA")
+
+        pil_viz_im = Image.new("RGBA", pil_base_im.size, (255, 255, 255, 0))
+        draw = ImageDraw.Draw(pil_viz_im, "RGBA")
+
+        for line_idx, line in enumerate(lines):
+            [(x1, y1), (x2, y2)] = line
+            if max(x1, y1, x2, y2) < 1.0:
+                x1 = x1 * img_w
+                y1 = y1 * img_h
+                x2 = x2 * img_w
+                y2 = y2 * img_h
+
+            draw.line(xy=[(x1, y1), (x2, y2)],
+                      fill=self.default_roi_color if line_color is None else line_color,
+                      width=self.default_outline_thickness if line_thickness is None else line_thickness)
+
+            # get text label
+            if labels is not None and len(labels) > line_idx:
+                label = labels[line_idx]
+            else:
+                label = f"line_{line_idx + 1}"
+            x0, y0 = int((x1 + x2) // 2), int((y1 + y2) // 2)
+            utils.put_text(
+                draw=draw,
+                font=self.default_font if label_font is None else label_font,
+                bbox=(x0, y0),
+                large_padding=True,
+                text=label,
+                text_color=self.label_color if label_color is None else label_color,
+                show_shadow=True,
+                bbox_thickness=None,
+                bbox_color=None
+            )
+
+        pil_out = Image.alpha_composite(pil_base_im, pil_viz_im)
+        cv_im_processed = cv2.cvtColor(np.array(pil_out), cv2.COLOR_RGBA2BGR)
+        return cv_im_processed
